# Copyright (c) 2019 Red Hat, Inc.
#
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.
from __future__ import absolute_import

from oslo_log import log

from tobiko import config
from tobiko.openstack.stacks import _advanced_vm

CONF = config.CONF
LOG = log.getLogger(__name__)


class OctaviaServerStackFixture(_advanced_vm.AdvancedServerStackFixture):
    has_floating_ip = False


class OctaviaOtherServerStackFixture(OctaviaServerStackFixture):
    pass
